/// <reference types="node" />
import { IMediaData } from "file/media";
import { AppProperties } from "./app-properties/app-properties";
import { ContentTypes } from "./content-types/content-types";
import { CoreProperties, IPropertiesOptions } from "./core-properties";
import { Document } from "./document";
import { SectionPropertiesOptions } from "./document/body/section-properties/section-properties";
import { FooterWrapper } from "./footer-wrapper";
import { FootNotes } from "./footnotes";
import { HeaderWrapper } from "./header-wrapper";
import { Media } from "./media";
import { Numbering } from "./numbering";
import { Hyperlink, Paragraph, PictureRun } from "./paragraph";
import { Relationships } from "./relationships";
import { Styles } from "./styles";
import { Table } from "./table";
export declare class File {
    private readonly document;
    private readonly styles;
    private readonly coreProperties;
    private readonly numbering;
    private readonly media;
    private readonly docRelationships;
    private readonly fileRelationships;
    private readonly headerWrapper;
    private readonly footerWrapper;
    private readonly footNotes;
    private readonly contentTypes;
    private readonly appProperties;
    private nextId;
    constructor(options?: IPropertiesOptions, sectionPropertiesOptions?: SectionPropertiesOptions);
    addParagraph(paragraph: Paragraph): void;
    createParagraph(text?: string): Paragraph;
    addTable(table: Table): void;
    createTable(rows: number, cols: number): Table;
    createImage(image: string): PictureRun;
    createImageData(imageName: string, data: Buffer, width?: number, height?: number): IMediaData;
    createHyperlink(link: string, text?: string): Hyperlink;
    addSection(sectionPropertiesOptions: SectionPropertiesOptions): void;
    createFootnote(paragraph: Paragraph): void;
    createHeader(): HeaderWrapper;
    createFooter(): FooterWrapper;
    createFirstPageHeader(): HeaderWrapper;
    readonly Document: Document;
    readonly Styles: Styles;
    readonly CoreProperties: CoreProperties;
    readonly Numbering: Numbering;
    readonly Media: Media;
    readonly DocumentRelationships: Relationships;
    readonly FileRelationships: Relationships;
    readonly Header: HeaderWrapper;
    readonly Headers: HeaderWrapper[];
    HeaderByRefNumber(refId: number): HeaderWrapper;
    readonly Footer: FooterWrapper;
    readonly Footers: FooterWrapper[];
    FooterByRefNumber(refId: number): FooterWrapper;
    readonly ContentTypes: ContentTypes;
    readonly AppProperties: AppProperties;
    readonly FootNotes: FootNotes;
}
